@@ -36,6 +36,7 @@ extern "C" {
 	#include <osmocom/gsm/protocol/gsm_04_08.h>
 	#include <osmocom/gsm/gsm_utils.h>
 	#include <osmocom/core/gsmtap_util.h>
+	#include <osmocom/core/application.h>
 }
 
 #include <arpa/inet.h>
@@ -48,6 +49,16 @@ extern "C" {
 
 extern void *tall_pcu_ctx;
 
+extern "C" {
+	/* e must make sure to initialize logging before the BTS static
+	 * constructors are executed below, as those call libosmocore APIs that
+	 * require logging already to be initialized. */
+	__attribute__((constructor)) static void early_init(void)
+	{
+		osmo_init_logging(&gprs_log_info);
+	}
+}
+
 static BTS s_bts;
 
 /**
@@ -649,7 +660,7 @@ int BTS::rcv_rach(uint16_t ra, uint32_t Fn, int16_t qta, uint8_t is_11bit,
 		}
 	} else {
 		// Create new TBF
-		#warning "Copy and paste with other routines.."
+		/* FIXME: Copy and paste with other routines.. */
 
 		if (is_11bit) {
 			tbf = tbf_alloc_ul_tbf(&m_bts, NULL, -1, 0,
