@@ -163,9 +163,9 @@ static int pcu_tx_data_req(uint8_t trx, uint8_t ts, uint8_t sapi,
 void pcu_l1if_tx_pdtch(msgb *msg, uint8_t trx, uint8_t ts, uint16_t arfcn,
 	uint32_t fn, uint8_t block_nr)
 {
+#ifdef ENABLE_DIRECT_PHY
 	struct gprs_rlcmac_bts *bts = bts_main_data();
 
-#ifdef ENABLE_DIRECT_PHY
 	if (bts->trx[trx].fl1h) {
 		l1if_pdch_req(bts->trx[trx].fl1h, ts, 0, fn, arfcn, block_nr,
 			msg->data, msg->len);
@@ -245,21 +245,33 @@ extern "C" int pcu_rx_data_ind_pdtch(uint8_t trx_no, uint8_t ts_no, uint8_t *dat
 	return pdch->rcv_block(data, len, fn, meas);
 }
 
+static int pcu_rx_data_ind_bcch(uint8_t *data, uint8_t len)
+{
+	struct gprs_rlcmac_bts *bts = bts_main_data();
+
+	if (len == 0) {
+		bts->si13_is_set = false;
+		LOGP(DL1IF, LOGL_INFO, "Received PCU data indication with empty SI13: cache cleaned\n");
+		return 0;
+	}
+
+	if (len != GSM_MACBLOCK_LEN) {
+		LOGP(DL1IF, LOGL_ERROR, "Received PCU data indication with SI13 with unexpected length %u\n", len);
+		return -EINVAL;
+	}
+
+	memcpy(bts->si13, data, GSM_MACBLOCK_LEN);
+	bts->si13_is_set = true;
+
+	return 0;
+}
+
 static int pcu_rx_data_ind(struct gsm_pcu_if_data *data_ind)
 {
 	struct gprs_rlcmac_bts *bts = bts_main_data();
 	int rc;
 	pcu_l1_meas meas;
-	meas.set_rssi(data_ind->rssi);
-#ifndef ENABLE_DIRECT_PHY
-	/* convert BER to % value */
-	meas.set_ber(data_ind->ber10k / 100);
-	meas.set_bto(data_ind->ta_offs_qbits);
-	meas.set_link_qual(data_ind->lqual_cb / 10);
-	LOGP(DL1IF, LOGL_DEBUG, "Data indication with raw measurements "
-	     "received: BER10k = %d, BTO = %d, Q = %d\n", data_ind->ber10k,
-	     data_ind->ta_offs_qbits, data_ind->lqual_cb);
-#endif
+
 	LOGP(DL1IF, LOGL_DEBUG, "Data indication received: sapi=%d arfcn=%d "
 		"block=%d data=%s\n", data_ind->sapi,
 		data_ind->arfcn, data_ind->block_nr,
@@ -267,10 +279,22 @@ static int pcu_rx_data_ind(struct gsm_pcu_if_data *data_ind)
 
 	switch (data_ind->sapi) {
 	case PCU_IF_SAPI_PDTCH:
+		meas.set_rssi(data_ind->rssi);
+#ifndef ENABLE_DIRECT_PHY
+		/* convert BER to % value */
+		meas.set_ber(data_ind->ber10k / 100);
+		meas.set_bto(data_ind->ta_offs_qbits);
+		meas.set_link_qual(data_ind->lqual_cb / 10);
+		LOGP(DL1IF, LOGL_DEBUG, "Data indication with raw measurements received: BER10k = %d, BTO = %d, Q = %d\n",
+		     data_ind->ber10k, data_ind->ta_offs_qbits, data_ind->lqual_cb);
+#endif
 		rc = pcu_rx_data_ind_pdtch(data_ind->trx_nr, data_ind->ts_nr,
 			data_ind->data, data_ind->len, data_ind->fn,
 			&meas);
 		break;
+	case PCU_IF_SAPI_BCCH:
+		rc = pcu_rx_data_ind_bcch(data_ind->data, data_ind->len);
+		break;
 	default:
 		LOGP(DL1IF, LOGL_ERROR, "Received PCU data indication with "
 			"unsupported sapi %d\n", data_ind->sapi);
